@@ -1,10 +1,11 @@
 from typing import Union
+
 from ..utils import get
 
 BASE_URL = "https://api.bilibili.com"
 
 
-async def get_user_info(uid: Union[int, str], *, auth=None, reqtype="both", **kwargs):
+async def get_user_info(uid: Union[int, str], *, auth=None, reqtype="app", **kwargs):
     """根据 UID 获取指定用户信息"""
     url = f"{BASE_URL}/x/space/acc/info"
     params = {"mid": uid}
@@ -19,7 +20,7 @@ async def get_videos(
     order: str = "pubdate",
     *,
     auth=None,
-    reqtype="both",
+    reqtype="app",
     **kwargs,
 ):
     """
